@@ -33,18 +33,6 @@ impl <T: MixedNum + MixedNumSigned + MixedWrapPhase + MixedTrigonometry + MixedO
     }
 }
 
-impl <T: MixedNum + MixedNumConversion<T2> + MixedZero, T2: MixedNum> MixedNumConversion<T2> for Cartesian<T>
-{
-    #[inline(always)]
-    fn mixed_from_num( number:T2 ) -> Self {
-        return Self{re:T::mixed_from_num(number), im:T::mixed_zero()};
-    }
-    #[inline(always)]
-    fn mixed_to_num( &self ) -> T2 {
-        return self.re.mixed_to_num();
-    }
-}
-
 impl <T: MixedNum + MixedNumSigned> ToCartesian<T> for Cartesian<T>
 {
     /// Converison to Complex<T>.
@@ -118,13 +106,39 @@ impl <T: MixedNum + MixedNumSigned + MixedSqrt + MixedPowi + MixedOps + MixedZer
 impl <T: MixedNum + MixedNumSigned + MixedAtan> Arg<T> for Cartesian<T>
 {
     /// Argument of the complex number.
+    /// 
+    /// ## Example
+    /// 
+    /// ```
+    /// use mixed_num::*;
+    /// use mixed_num::traits::*;
+    ///
+    /// let polar_num = Polar::new(1f32,0.5f32);
+    ///  
+    /// let cartesian_num = polar_num.to_cartesian();
+    /// 
+    /// assert_eq!{ cartesian_num.arg().to_string(), "0.5" };
+    /// ``` 
     #[inline(always)]
     fn arg( &self ) -> T
     {
-        return self.re.mixed_atan2(self.im);
+        return self.im.mixed_atan2(self.re);
     }
 
     /// Angle of the complex number.
+    /// 
+    /// ## Example
+    /// 
+    /// ```
+    /// use mixed_num::*;
+    /// use mixed_num::traits::*;
+    ///
+    /// let polar_num = Polar::new(1f32,0.5f32);
+    ///  
+    /// let cartesian_num = polar_num.to_cartesian();
+    /// 
+    /// assert_eq!{ cartesian_num.ang().to_string(), "0.5" };
+    /// ``` 
     #[inline(always)]
     fn ang( &self ) -> T
     {
@@ -478,4 +492,8 @@ impl <T: MixedReal + MixedNumSigned + MixedSin + MixedExp + core::ops::MulAssign
         r_value.im *= scale;
         return r_value;
     }
+}
+
+impl <T: MixedNum + MixedNumSigned> MixedNum for Cartesian<T>
+{
 }
\ No newline at end of file
